@@ -2,7 +2,8 @@ import os
 import tokenize
 from typing import Iterator, List, Tuple
 
-from grimp.application.ports.filesystem import AbstractFileSystem
+from grimp.application.ports.filesystem import AbstractFileSystem, BasicFileSystem
+from grimp import _rustgrimp as rust  # type: ignore[attr-defined]
 
 
 class FileSystem(AbstractFileSystem):
@@ -18,7 +19,7 @@ class FileSystem(AbstractFileSystem):
         return os.path.dirname(filename)
 
     def walk(self, directory_name: str) -> Iterator[Tuple[str, List[str], List[str]]]:
-        yield from os.walk(directory_name)
+        yield from os.walk(directory_name, followlinks=True)
 
     def join(self, *components: str) -> str:
         return os.path.join(*components)
@@ -44,3 +45,6 @@ class FileSystem(AbstractFileSystem):
             os.makedirs(dirname)
         with open(file_name, "w") as file:
             print(contents, file=file)
+
+    def convert_to_basic(self) -> BasicFileSystem:
+        return rust.RealBasicFileSystem()
