@@ -51,7 +51,7 @@ class ModuleFinder(modulefinder.AbstractModuleFinder):
                 dirs.remove(d)
 
             for filename in files:
-                if self._is_python_file(filename):
+                if self._is_python_file(filename, dirpath):
                     yield self.file_system.join(dirpath, filename)
 
     def _should_ignore_dir(self, directory: str) -> bool:
@@ -59,16 +59,33 @@ class ModuleFinder(modulefinder.AbstractModuleFinder):
         # Skip adding directories that are hidden.
         return directory.startswith(".")
 
-    def _is_python_file(self, filename: str) -> bool:
+    def _is_python_file(self, filename: str, dirpath: str) -> bool:
         """
         Given a filename, return whether it's a Python file.
 
+        Files with extra dots in the name won't be treated as Python files.
+
         Args:
             filename (str): the filename, excluding the path.
         Returns:
             bool: whether it's a Python file.
         """
-        return not filename.startswith(".") and filename.endswith(".py")
+        # Ignore hidden files.
+        if filename.startswith("."):
+            return False
+
+        if not filename.endswith(".py"):
+            return False
+
+        # Ignore files like some.module.py.
+        if filename.count(".") > 1:
+            logger.warning(
+                "Warning: skipping module with too many dots in the name: "
+                f"{dirpath}{self.file_system.sep}{filename}"
+            )
+            return False
+
+        return True
 
     def _module_name_from_filename(
         self, package_name: str, filename_and_path: str, package_directory: str
@@ -84,9 +101,9 @@ class ModuleFinder(modulefinder.AbstractModuleFinder):
         """
         internal_filename_and_path = filename_and_path[len(package_directory) :]
         internal_filename_and_path_without_extension = internal_filename_and_path[1:-3]
-        components = [
-            package_name
-        ] + internal_filename_and_path_without_extension.split(self.file_system.sep)
+        components = [package_name] + internal_filename_and_path_without_extension.split(
+            self.file_system.sep
+        )
         if components[-1] == "__init__":
             components.pop()
         return ".".join(components)
