@@ -7,6 +7,12 @@ from grimp.domain.valueobjects import Module
 from .filesystem import AbstractFileSystem
 
 
+@dataclass(frozen=True)
+class ModuleFile:
+    module: Module
+    mtime: float
+
+
 @dataclass(frozen=True)
 class FoundPackage:
     """
@@ -15,7 +21,7 @@ class FoundPackage:
 
     name: str
     directory: str
-    modules: FrozenSet[Module]
+    module_files: FrozenSet[ModuleFile]
 
 
 class AbstractModuleFinder(abc.ABC):
